# file: lk_boxes.tcl
#
# This proc creates the multiple listboxes that are used to display
# most of the program data
#

# Based heavily from work by Jeffrey Hobbs <jhobbs@cs.uoregon.edu>
#                            Fri, 15 Dec 1995 10:00:51 -0800       

proc make_listboxes {w listboxes} {
    
    set relief sunken

    global LB_W
    global LB_lboxes
    global vars
    global item_number
    global title_name
    global fonts
    global last_item_number

    set LB_W $w
    set LB_lboxes ""
    
    
    # this proc highlights the current item number
    #
    proc LBview {} {
	global item_number
	global p

	LBset select clear 0 end
	LBset select set [expr $item_number -1]
	LBset see [expr $item_number -1]

	# see this in the plot
	#
	canvas_see $p.display_f.canvas item_$item_number 
	refresh_comment
	refresh_current $p.display_f.canvas item_$item_number $item_number
	
    }

    # this proc makes number current, and highlights it
    #
    proc LBviewit {number} {
	global item_number 
	global last_item_number
	set last_item_number $item_number
	set item_number $number
	LBview
    }

    # this proc makes named item current, and highlights it
    #
    proc LBviewitnamed {name} {
	set num [get_list_num $name]
	incr num
	LBviewit $num 
    }

    # this proc sets the listboxes all at once
    #
    proc LBset args {

	global LB_lboxes
	
	foreach lb $LB_lboxes {
	    eval $lb $args
	}
    }
    
    # this proc allows the scrollbar to control all listboxes
    #
    proc LBscroll args {
	
	global LB_W
	eval $LB_W.sy set $args
	LBset yview moveto [lindex $args 0]
    }

    # define frames to encapsulate the area
    #
    frame $LB_W.f_sy -relief $relief -border 3
    
    # space holder, does nothing
    #
    label $LB_W.l_sy -text " " -font $fonts(10)

    # this one scrollbar will control all the listboxes
    #
    scrollbar $LB_W.sy -orient v -command "LBset yview" -relief ridge

    pack $LB_W.f_sy -side right -fill y 
    pack $LB_W.l_sy -in $LB_W.f_sy -side top ;# -fill both -expand true
    pack $LB_W.sy -in $LB_W.f_sy -fill y -side bottom -expand true


    bind $LB_W.sy <Button-3> "help_box scrollbar"
    

    # define each of the listboxes
    #
    foreach lb $listboxes {
	
	global title_name
	frame $LB_W.f_$lb -relief $relief -border 3
	
	listbox $LB_W.$lb -export no -selectmode browse -yscrollcom LBscroll \
		-font $fonts(12)

	lappend LB_lboxes $LB_W.$lb

	label $LB_W.l_$lb -text $title_name($lb) -font $fonts(12)

	pack $LB_W.f_$lb -side left -fill both -expand true
	pack $LB_W.l_$lb -side top -fill x -in $LB_W.f_$lb 
	pack $LB_W.$lb -side top -fill both -expand true -in $LB_W.f_$lb
    }
    
    bind_listboxes

}

proc bind_listboxes {} {
    
    global LB_lboxes last_item_number item_number title_name

    # make bindings common to each listbox
    #
    foreach lb $LB_lboxes {

	# a single press, hightlight this item
	#
	bind $lb <ButtonPress-1> {
	    set last_item_number $item_number
	    set item_number [expr [%W nearest %y] +1]
#	    view_item $item_number
	    refresh_comment
	    LBview
	}

	# keep the current item hightlighted through motion
	#
	bind $lb <B1-Motion> {
	    set last_item_number $item_number
	    LBset select clear 0 end
	    set item_number [expr [%W nearest %y] +1]
	    LBset see $item_number
	    refresh_comment
	    LBview
	}

	# a single release, hightlight this item
	#
	bind $lb <ButtonRelease-1> {
	    set last_it_num $item_number
	    set item_number [expr [%W nearest %y] +1]
#	    view_item $item_number
	    refresh_comment
	    LBview
	}

	# double click selects the item to be configured
	#
	bind $lb <Double-Button-1> {
	    refresh_comment
	    view_item $item_number
	}

	# help binding
	#
	set name [string range $lb [expr [string last "." $lb] +1] end]
	bind $lb <Button-3> "help_box \"$title_name($name)\""
    }
}    
# end of file
#
