# file: lk_canvas_see.tcl
#

## "see" method alternative for canvas
## Aligns the named item as best it can in the middle of the screen
## Behavior depends on whether -scrollregion is set
##
## c	- a canvas widget
## item	- a canvas tagOrId
proc canvas_see {c item} {
    global ditem_sep
    set box [$c bbox $item]

    if [string match {} $box] return
    
    foreach {xs ys xf yf} $box {top btm} [$c yview] \
            {left right} [$c xview] \
	    {x_min y_min x_max y_max} [$c cget -scrollreg] {

	set xs [expr $xs - $ditem_sep]
	set width [expr $x_max - $x_min]
	set right [expr $right * $width]
	set left [expr $left * $width]

	set height [expr $y_max - $y_min]
	set top [expr $top * $height]
	set btm [expr $btm * $height]
	
	# see if the display is to far over to the right for the image 
	#  ie: item number to small to be displayed
	#
	if { $xs < $left } {

	    $c xview moveto [expr (0.0 + $xs-$x_min)/$width]
	} else {
	    
	    # see if the display is to far over to the left for the image
	    #    ie: item number to large to be displayed
	    #
	    if {$xf > $right} {
		$c xview moveto [expr ($xf-$x_min-($right-$left))/$width]
	    }
	}
	# see if the display is to far down for the image 
	#
	if { $ys < $top } {

	    $c yview moveto [expr (0.0 + $ys-$y_min)/$height]
	} else {
	    
	    # see if the display is to far up for the image
	    #
	    if {$yf > $btm} {
		$c yview moveto [expr ($yf-$y_min-($btm-$top))/$height]
	    }
	}


    }

    # draw a box around the current item (after deleting the current box)
    # 
    #    catch {$c delete current_item}
    #    $c create line $xs $ys $xs $yf $xf $yf $xf $ys $xs $ys \
	    #	    -tags current_item -width 5
    #    $c focus current_item
	    
}

proc refresh_current {c item item_num} {
    global current_box current_ref_line current_jmp_line
    global plot_ref_arrows plot_jmp_arrows

    set box [$c bbox $item]

    if [string match {} $box] return
    catch {$c delete current_item}
    foreach {xs ys xf yf} $box {
	set current_box {line $xs $ys $xs $yf $xf $yf $xf $ys $xs $ys \
		-tags current_item -width 5}
	eval "$c create $current_box"
	set current_ref_line [lindex $plot_ref_arrows [expr $item_num -1]]
	if {$current_ref_line != ""} {
	    eval "$c create $current_ref_line -width 3\
		    -tags \"data_flow dflow_$item_num current_item\""
	}
	set current_jmp_line [lindex $plot_jmp_arrows [expr $item_num -1]]
	if {$current_jmp_line != ""} {
	    eval "$c create $current_jmp_line -width 3\
		    -tags \"control_flow cflow_$item_num current_item\""
	}
    }
	
}
# end of file
#
