#! /usr/local/bin/wish -f
# file: lk_data.tcl 
# 

# In an attempt to create more re-usable code, this file contains all
# of the labels used in the GUI.
#

global items_defs
global item_params
global entry_field

# This is the list of what parameters are used by the different types of items.
#
# the format of the nested list is as follows:
#    type of item
#    description of item's parameters (list of):
#        variable name: valid TCL variable name only
#                       this is what is copied directly into the param file
#        description: this is what the user sees as the label
#    bitmap filename for use in the plot
#
# the rest of the parameters necessary to construct the list for
# display_list are obtained from the item_params definition, below
#
set items_defs {
    {
	"wait for call" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	    { "conf_channel" "conference" }
	}
	"it_wait.gif"
	"it_wait.xbm"
    }
    {
	"dial" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	    { "filename_0" "connecting message" }
	    { "filename_1" "busy message" }
	    { "filename_2" "no connection message" }
	    { "dtmf" "number to dial (static)" }
	    { "ref_name" "number to dial (referenced)" }
	    { "jump_name" "jump to if no connection" }
	    { "conf_channel" "conference" }
	}
	"it_dial.gif"
	"it_dial.xbm"
    }
    {
	"hangup" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "filename_0" "goodbye message" }
	    { "name" "name of item" }
	    { "conf_channel" "conference" }
	}
	"it_hangup.gif"
	"it_hangup.xbm"
    }


    { 
	"play" { 
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	    { "filename_0" "filename to play (static)" }
	    { "abort_keys" "play abort keys" }
	    { "speaker_mode" "max number of digits" }
	    { "wait_interval" "wait time between digits" }
	    { "ref_name" "filename to play (referenced)" }
	    { "jump_name" "jump if dtmf keys are hit" }
	    { "conf_channel" "conference" }
	} 
	"it_play.gif"
	"it_play.xbm"
    }
    {
	"record" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	    { "filename_template" "filename template" }
	    { "conf_filename_template" "conf filename template" }
	    { "speaker_mode" "speaker mode" }
	    { "conf_channel" "conference" }
	    { "wait_interval" "non-signal-detected time" }
	    { "sample_frequency" "sample frequency" }
	    { "initial_pad" "initial pad time" }
	    { "final_pad" "final pad time" }
	    { "max_initial_silence" "maximum initial silence" }
	    { "max_final_silence" "maximum final silence" }
	    { "max_duration" "maximum duration" }
	    { "min_energy" "minimum detection energy" }	
	}
	"it_record.gif"
	"it_record.xbm"
    }
    {
	"synthesize" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	    { "abort_keys" "abort keys" }
	    { "filename_0" "filename for digit 0" }
	    { "speaker_mode" "telephone number?" }
	    { "dtmf" "data string (static)" }
	    { "ref_name" "data string (referenced)" }
	    { "conf_channel" "conference" }
	}
	"it_synthesize.gif"
	"it_synthesize.xbm"
    }


    {
	"get dtmf" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	    { "abort_keys" "terminal key" }
	    { "wait_interval" "key timeout" }
	    { "speaker_mode" "max number of digits" }
	    { "ref_name" "short circuit data (referenced)" }
	    { "conf_channel" "conference" }
	    { "jump_name" "jump to on time out" }
	}
	"it_get_dtmf.gif"
	"it_get_dtmf.xbm"
    }
    { 
	"check dtmf" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	    { "filename_0" "list of numbers" }
	    { "dtmf" "specific data string" }
	    { "ref_name" "string to check (referenced)" }
	    { "jump_name" "jump to if no match" }
	}	    
	"it_check_dtmf.gif"
	"it_check_dtmf.xbm"
    }
    {
	"save number" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	    { "ref_name" "data string (referenced)" }
	    { "filename_template" "filename template" }
	}
	"it_save.gif"
	"it_save.xbm"
    }

    {
	"conference connect" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	}
	"it_conf_con.gif"
	"it_conf_con.xbm"
    }
    {
	"conference disconnect" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	}
	"it_conf_discon.gif"
	"it_conf_discon.xbm"
    }

    {
	"shell" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	    { "shell_command" "command to execute" }
	    { "speaker_mode" "background process?" }
	    { "dtmf" "data string (static)" }
	    { "ref_name" "data string (referenced)" }
	    { "jump_name" "jump to on error" }
	}
	"it_shell.gif"
	"it_shell.xbm"
    }
    {
	"mail" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	    { "address" "email address" }
	    { "filename_0" "file to include" }
	    { "dtmf" "data string (static)" }
	    { "ref_name" "data string and/or file (referenced)" }
	}
	"it_mail.gif"
	"it_mail.xbm"
    }
    {
	"direct jump" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	    { "jump_name" "jump to item" }
	}
	"it_jump.gif"
	"it_jump.xbm"
    }
    {
	"set number" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	    { "ref_name" "target item (referenced)" }
	    { "dtmf" "value" }
	}
	"it_set_num.gif"
	"it_set_num.xbm"
    }
    {
	"iterate" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	    { "initial" "initial value" }
	    { "step" "step value" }
	}
	"it_iterate.gif"
	"it_iterate.xbm"
    }
    {
	"kill program" {
	    { "comment" "comment" }
	    { "type" "type of item" }
	    { "name" "name of item" }
	}
	"it_die.gif"
	"it_die.xbm"
    }

	
}

# these are the possible parameters available to an item. 
#
# the format is as follows:
#    variable name: valid TCL variable name only
#                   this is what is copied directly into the param file
#    bitmap file: the bitmap shown with the item
#    default: the default value for the variable to have
#    value(s): if this is "_ISIP_ENTRY_FIELD", then an entry widget is
#              created, else all remaining items in the list become
#              radiobuttons 
#

# note: the only difference between this list and the general
# parameters list (a full list that can be sent to display_list) is
# that the third parameter, description, is missing. This is because
# different items use different parameters in different ways. So, when
# an item defines which parameters it is going to use, it also defines
# in what ways it is going to use them (as defined in item_defs. To
# make a complete list for a given type of item, each parameter name
# appearing in item_defs is replaced with the available item paramater
# definitions (item_params), inserting the description as defined in
# the item_defs.
#

set item_params {
    { "type" "" "" "" "wait for call" "dial" "hangup" \
	    "play" "record" "synthesize" \
	    "get dtmf" "check dtmf" "save number" "set number"\
	    "conference connect" "conference disconnect" \
	    "shell" "mail" "direct jump" "iterate" "kill program" }
    
    { "abort_keys" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "filename_template" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "conf_filename_template" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "wait_interval" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "filename_0" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "filename_1" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "filename_2" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "speaker_mode" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "dtmf" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "name" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "ref_name" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "jump_name" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "shell_command" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "address" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "conf_channel" "" "" "master" "master" "slave" "both" }
    { "out_filename" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "sample_frequency" "" "" "8000.0" "_ISIP_ENTRY_FIELD" }
    { "initial_pad" "" "" ".25" "_ISIP_ENTRY_FIELD" }
    { "final_pad" "" "" ".5" "_ISIP_ENTRY_FIELD" }
    { "max_initial_silence" "" "" "7.0" "_ISIP_ENTRY_FIELD" }
    { "max_final_silence" "" "" "3.0" "_ISIP_ENTRY_FIELD" }
    { "max_duration" "" "" "10.0" "_ISIP_ENTRY_FIELD" }
    { "min_energy" "" "" "500000.0" "_ISIP_ENTRY_FIELD" }
    { "comment" "" "" "" "_ISIP_ENTRY_FIELD" }
    { "initial" "" "" "0" "_ISIP_ENTRY_FIELD" }
    { "step" "" "" "1" "_ISIP_ENTRY_FIELD"} 
}

# note the format for each sublist:
#    variable name: valid TCL variable name only
#                   this is what is copied directly into the param file
#    description: this is what the user sees as the label
#    bitmap file: the bitmap shown with the item
#    default: the default value for the variable to have
#    value(s): if this is "_ISIP_ENTRY_FIELD", then an entry widget is created,
#              else all remaining items in the list become radiobuttons
#
set general_params {
    { "comment" "comment" "" "Set up the general parameters" \
	    "_ISIP_ENTRY_FIELD" }
	    
    { "num_items" "number of items" \
	    "" 20 "_ISIP_ENTRY_FIELD" }
    { "database_name" "database name" \
	    "" "Test database" "_ISIP_ENTRY_FIELD" }
    { "monitor_command" "monitor command" \
	    "" "$LINKON/bin/$ISIP_BINARY/lk_run_monitor" "_ISIP_ENTRY_FIELD" }
    { "program_name" "program name" \
	    "" "Test program" "_ISIP_ENTRY_FIELD" }
    { "admin_alias" "Administrative mail alias" \
	    "" "admin@mydomain.edu" "_ISIP_ENTRY_FIELD" }
    { "speaker_directory_format" "speaker directory format" "" "" \
	    "_ISIP_ENTRY_FIELD" }
    { "disk_info" "needed disk space" \
	    "" 10 "_ISIP_ENTRY_FIELD" }
    { "data_collection_system" "data collection system" \
	    "" "not defined" "not defined" 0 1 2 3 4 5 6 7}
    { "teleconferencing_system" "teleconferencing system" \
	    "" "not defined" "not defined" 0 1 2 3 4 5 6 7}
    { "database_logfile" "database logfile" \
	    "" "/tmp/logfile.text" "_ISIP_ENTRY_FIELD" }
    { "starting_speaker_number" "starting speaker number" "" -1 \
	    "_ISIP_ENTRY_FIELD" }
    { "progress_file" "progress file" "" ""\
	    "_ISIP_ENTRY_FIELD" }
}

# define the pnuemonics
global PNUEM
set PNUEM {
    { "wait for call" WCAL }
    { "dial" DIAL }
    { "hangup" HANG }
    { "play" PLAY }
    { "record" RECD }
    { "synthesize" SYNS }
    { "get dtmf" GETD }
    { "check dtmf" CHKN }
    { "save number" SVEN }
    { "conference connect" CNFC }
    { "conference disconnect" CNFD }
    { "shell" SHEL }
    { "mail" MAIL }
    { "direct jump" JUMP }
    { "set number" SETN }
    { "iterate" ITER}
    { "kill program" DIE}
}

# end of file
#


