# file: lk_delete_item.tcl
#
# This proc cuts the current item and places it onto the cut buffer
#
proc copy_item {} {
    global num_items
    global num_items_hist
    global item_number
    global item_list
    global item_params
    global deleted_list
    global LB_W
    global save_flag need_save
    global vars

    # make sure item number is valid
    #
    if {($item_number > 0)&&($item_number <= $num_items)} {


	# find the name of the item in the list of items
	#
	set name [lindex $item_list [expr $item_number -1]]
	set number [lsearch $item_list $name]
	
	# first delete the current deleted item, if it exists
	#
	if {$deleted_list != ""} {
	    foreach param $item_params {
		set pname [lindex $param 0]
		catch {unset vars($deleted_list,$pname) }
	    }
	}

	# copy this item to a new item at the end, and set that to
	# the deleted list
	#
	incr num_items_hist
	set new_name "it_$num_items_hist"
	foreach param $item_params {
	    set pname [lindex $param 0]
	    catch { set vars($new_name,$pname) $vars($name,$pname) }
	}
	
#	set save_flag $need_save

	# place it onto the deleted space
	#
	set deleted_list $new_name
    }
}

# this procedure kills an item and does not disturb the cut buffer
#
proc kill_item {} {
    global deleted_list item_params save_flag need_save
    
    set temp_deleted_list $deleted_list
    set deleted_list ""
    delete_item

    # now delete all the parameters
    #
    if {$deleted_list != ""} {
	foreach param $item_params {
	    set pname [lindex $param 0]
	    catch {unset vars($deleted_list,$pname) }
	}
    }
    set deleted_list $temp_deleted_list
    set save_flag $need_save

}

proc delete_item {} {
    
    global num_items
    global num_items_hist
    global item_number
    global item_list
    global item_params
    global deleted_list
    global LB_W
    global save_flag need_save
    global vars

    # where to find the listboxes
    #
    set w $LB_W

    # make sure item number is valid
    #
    if {($item_number > 0)&&($item_number <= $num_items)} {


	# find the name of the item in the list of items
	#
	set name [lindex $item_list [expr $item_number -1]]
	set number [lsearch $item_list $name]
	
	# set the save flag
	#
	set save_flag $need_save
	
	# first delete the current deleted item, if it exists
	#
	if {$deleted_list != ""} {
	    foreach param $item_params {
		set pname [lindex $param 0]
		catch {unset vars($deleted_list,$pname) }
	    }
	}

	# place it onto the deleted space
	#
	set deleted_list $name
	
	# remove it from the list of current items
	#
	set item_list [lreplace $item_list $number $number]
	
	# possibly kill the editing window for this item
	#
	if { [winfo exists ".$name"] != 0 } {
	    destroy ".$name"
	}
	
	$w.it_type delete [expr $item_number -1]
	$w.it_name delete [expr $item_number -1]
	$w.it_ref_name delete [expr $item_number -1] 
	$w.it_jump_name delete [expr $item_number -1]
	$w.it_pnuem delete [expr $item_number -1]

	incr_item_number -1
	incr num_items -1

	# refresh the number count
	#
	$w.it_num delete 0 end

	for {set i 1} { $i <= [llength $item_list] } { incr i} {
	    $w.it_num insert end $i
	}
	plot
	LBview
    }
}

# end of file
#
