# file: lk_display.tcl
#
# This file sets up the main control widget
#

# get rid of the toplevel
#
wm withdraw .
set p ".main"

toplevel $p

# communicate with the window manager
#
wm protocol $p WM_DELETE_WINDOW {exit_cc}
wm geometry $p "+0+0"
wm title $p "Linkon Application Builder"

# base frames
#
frame $p.top_f
frame $p.body_f
frame $p.control_f
frame $p.display_f
frame $p.body_f.items_f

frame $p.modeline_f -borderwidth 3 -relief ridge
frame $p.minibuffer_f -borderwidth 3 -relief ridge
frame $p.mbar_f -relief sunken -bd 2

# the menu bar creation is fairly involved, so it was modulized
#
gen_menu $p.mbar_f

pack $p.mbar_f -side top -fill x -padx 3 -pady 3
pack $p.top_f -side top -fill both -expand true -padx 3 -pady 3
pack $p.minibuffer_f -side top -fill x -padx 3 -pady 3
pack $p.body_f -side top -fill both -expand true -padx 3 -pady 3
pack $p.modeline_f -side top -fill x -padx 3 -pady 3

pack $p.display_f -side right -in $p.top_f -fill both -expand true

$p.display_f configure -background black
pack $p.body_f.items_f -side top -fill both -expand true


# create the modeline.

# this is reminiscent of emacs, having one line display a wealth of
# compact useful information.
#

label $p.modeline_f.l_fname -text "" -font $fonts(12)

# for ease of display updating, we use disabled entry widgets, making them
# look like the label widgets. A disabled entry widget cannot recieve input
#
entry $p.modeline_f.e_fname -textvariable filename -width 50 -state disabled \
	-relief flat -borderwidth 0 -font $fonts(12)
bind $p.modeline_f.e_fname <Button-3> "help_box \"ap filename\""


# this is the item number indicator
#
label $p.modeline_f.l_itnum -text "It #" -font $fonts(12)
bind $p.modeline_f.l_itnum <Button-3> "help_box \"item number label\""

entry $p.modeline_f.e_itnum -textvariable item_number -width $len_nitems \
	-state disabled -relief flat -borderwidth 0 -font $fonts(12)
bind $p.modeline_f.e_itnum <Button-3> "help_box \"item number\""

label $p.modeline_f.l_numits -text "/" -font $fonts(12)
bind $p.modeline_f.l_numits <Button-3> "help_box \"item number label\""

entry $p.modeline_f.e_numits -textvariable num_items -width $len_nitems \
	-state disabled -relief flat -borderwidth 0 -font $fonts(12)
bind $p.modeline_f.e_numits <Button-3> "help_box \"num items\""

# create the save flag display widget
#
entry $p.modeline_f.save -textvariable save_flag -state disabled \
	-width [string length $no_save] \
	-relief flat -borderwidth 0 -font $fonts(12)
bind $p.modeline_f.save <Button-3> "help_box \"save flag\""

pack $p.modeline_f.save $p.modeline_f.l_fname -side left

pack $p.modeline_f.e_numits $p.modeline_f.l_numits \
	$p.modeline_f.e_itnum $p.modeline_f.l_itnum \
	-side right -padx 2 -pady 2
pack $p.modeline_f.e_fname -side left -pady 2 -fill x -expand true



# create the minibuffer (used for comments)
#
label $p.minibuffer_f.comment -justify left -anchor w -font $fonts(12)
pack $p.minibuffer_f.comment -anchor w -fill both -padx 5

$p.minibuffer_f.comment configure -text \
	"Review the help menu for help starting out"
bind $p.minibuffer_f.comment <Button-3> "help_box comment"


# create the listboxes that will hold the user data for each item
#
make_listboxes $p.body_f.items_f $item_boxes

$p.body_f.items_f.it_num configure -width $len_nitems
$p.body_f.items_f.it_pnuem configure -width 6
$p.body_f.items_f.it_type configure -width 22
$p.body_f.items_f.f_sy configure -width 14
$p.body_f.items_f.l_sy configure -width 1
$p.body_f.items_f.sy configure -width 14

wm protocol $p WM_RESIZE_WINDOW {
    puts "redrawing"
    $p.body_f.items_f.it_num configure -width $len_nitems
    $p.body_f.items_f.it_pnuem configure -width 6
    $p.body_f.items_f.it_type configure -width 22
    $p.body_f.items_f.f_sy configure -width 14
    $p.body_f.items_f.l_sy configure -width 1
    $p.body_f.items_f.sy configure -width 14
    update
}

# create the canvas used for displaying
#
set w $p.display_f
$w configure -relief sunken -border 3 
frame $w.right -width 10 -height $canv_height
frame $w.box -height 23 
canvas $w.canvas -borderwidth 3 -relief ridge \
	-yscrollcommand "$w.yscroll set" \
	-xscrollcommand "$w.xscroll set" \
	-height $canv_height
scrollbar $w.yscroll -command "$w.canvas yview" -relief flat 

scrollbar $w.xscroll -command "$w.canvas xview" -orient horizontal \
	-relief flat

bind $w.canvas <Control-l> {plot}

pack $w.right -side right -fill y 
pack $w.box -side bottom -in $w.right
pack $w.yscroll -in $w.right -side top -fill y -expand true
pack $w.canvas -side top -fill both -expand true
$w.right configure -width 23

bind $w.canvas <Button-3> "help_box plotting"

pack $w.xscroll -side bottom -fill x

proc follow_param {param} {
    global item_number item_list vars
    set item [lindex $item_list [expr $item_number-1]] 
    catch {
	set it_param_name $vars($item,$param)
	set param_num [expr [get_named_it_num $it_param_name] +1]
	LBviewit $param_num
    }
}
bind $p <Control-z> suspend
bind $p <Control-q> exit_cc
bind $p <Control-c> copy_item
bind $p <Control-d> kill_item
bind $p <Control-x> delete_item
bind $p <Control-v> re_insert_item
bind $p <Control-f> {incr_item_number 1 redraw}
bind $p <Control-b> {incr_item_number -1 redraw}
bind $p <Control-F> {incr_item_number 5 redraw}
bind $p <Control-B> {incr_item_number -5 redraw}
bind $p <Control-a> {incr_item_number [expr 0 - $num_items] redraw}
bind $p <Control-e> {incr_item_number $num_items redraw}
bind $p <Right> {incr_item_number +1 redraw}
bind $p <Left> {incr_item_number -1 redraw}
bind $p <Control-Right> {incr_item_number +5 redraw}
bind $p <Control-Left> {incr_item_number -5 redraw}
bind $p <Control-g> {pop_item_number}

bind $p <Down> {follow_param ref_name}
bind $p <Up> {follow_param jump_name}
bind $p <Escape> {
    if {[winfo exists ".error"] != 0} {
	destroy ".error"
    } else {
	pop_item_number
    }
}


global last_item_number
set last_item_number 0
proc pop_item_number {} {
    global item_number last_item_number
    set val [expr $last_item_number - $item_number]
    incr_item_number $val redraw
}

proc incr_item_number {step args} {
    global item_number num_items last_item_number
    set num $item_number
    if {$step > 0} {
	if {[expr $num_items - $step] < $item_number} {
	    set num $num_items
	} else {
	    incr num $step
	}
    } else {
	if {$item_number <=  [expr 0 - $step]} {
	    set num 1
	} else  {
	    incr num $step
	}
    }
    if {[llength $args] > 0} {
	LBviewit $num
    } else {
	set last_item_number $item_number
	set item_number $num
    }
}

# method to suspend the process, iconifying all windows
#
proc suspend {} {
    global p
    global item_list

    # withdraw windows one by one, to reduce the chance of TCL hanging
    # on exit
    #
    wm iconify $p
    set list $item_list
    foreach item [concat $list "help" "exit" "filesel" "progress"] {
	set w ".$item" 
	if { [winfo exists $w] != 0 } {
	    wm iconify $w
	}
    }
}

# create the images to be used by item types
#
foreach item_def $items_defs {
    set type [lindex $item_def 0]
    set file [lindex $item_def 2]
    set p_file [lindex $item_def 3]

    global images
    global p_images

    set pnuem [get_pnuem "$type"]
    
    if { $file == "" } {
	set file $default_plot_graphic
    }
    set file "$graphics_dir/$file"

    image create photo images($pnuem)
    images($pnuem) read $file


    $p.display_f.canvas bind "item_type_$pnuem" <ButtonRelease-3> \
	    "help_box \"$type\""   

    if { $p_file == "" } {
	set file $default_print_graphic
    }
    set p_file "$graphics_dir/$p_file"
    set p_images($pnuem) $p_file

}

# netscape'ish binding
#
bind Entry <Control-u> {
    set foo [%W cget -textvariable]
    set $foo ""
}

# end of file
#
