# file: lk_display_list.tcl
#

# this procedure displays a parameter list into a widget named .$name
#

proc display_list { param_list name title} {

    global default_graphic
    global save_flag
    global need_save
    global graphics_dir
    global help_prog_name
    global fonts

    set w ".$name"
    global entry_length

    # if the widget already exists, don't recreate it
    #
    if { [winfo exists $w] != 0 } {
	
	wm deiconify $w
	raise $w
	
    } else {
    
	# create the new widget
	#
	toplevel $w
	wm title $w "$title"
	wm geometry $w -0-20

	bind $w <Enter> \
		"refresh_item_named $name"

	bind $w <Escape> "plot; destroy $w"

	# only import the global vars if neccesary
	#
	global vars

	# set up the general stuff
	#
	set i -1
	foreach param $param_list {
	    incr i
	    set var [lindex $param 0]
	    set label [lindex $param 1]
	    frame $w.f_$var -relief ridge -border 4
	    pack $w.f_$var -side top -padx 5 -fill both -expand true
	    
	    set graphic [lindex $param 2]
	    
	    if { $graphic == "" } {
		set graphic $default_graphic
	    }
	    label $w.f_$var.g_$var -bitmap "@$graphics_dir/$default_graphic"
	    catch { $w.f_$var.g_$var configure \
		    -bitmap "@$graphics_dir/$graphic" }
	    bind $w.f_$var.g_$var <Button-3> "help_box \"$label\"" 

	    
	    label $w.f_$var.l_$var -text $label -anchor w -width 26 \
		    -font $fonts(12)
	    bind $w.f_$var.l_$var <Button-3> "help_box \"$label\"" 
	    
	    pack $w.f_$var.g_$var -side left -padx 3
	    pack $w.f_$var.l_$var -side left -fill y 
	    
	    if { $var == "type" } {
		set type [lindex $param 4]
		set vars($name,$var) $type
		set pnuem [get_pnuem "$type"]
		label $w.f_$var.tl_$var -text "$pnuem: $type" \
			-font $fonts(12)
		bind $w.f_$var.tl_$var <Button-3> \
			"help_box \"$type\""
		
		
		# create the brief description of the item, right below
		# the item type
		#
		set text [exec $help_prog_name "$type"]
		set beg [string first "SYNOPSIS:" "$text"]
		set text [string range "$text" $beg end ]
		set end_num [string first "\n" "$text"]
		set text [string range "$text" 10 [expr $end_num -1] ]

		message $w.f_$var.tm_$var -padx 10 -aspect 700 \
			-text "$text" -font $fonts(10)
		pack $w.f_$var.tl_$var -side left 
		pack $w.f_$var.tm_$var -side left -fill y \
			-padx 3
		bind $w.f_$var.tm_$var <Button-3> \
			"help_box \"$type\""
		bind $w.f_$var.tl_$var <Button-3> "help_box \"$type\""
	    } elseif { [lindex $param 4] == "_ISIP_ENTRY_FIELD" } {
		if { [catch { set temp $vars($name,$var) } ] != 0 } {
		    set vars($name,$var) [lindex $param 3]
		}
		entry $w.f_$var.e_$var -textvariable vars($name,$var) \
			-width $entry_length -font $fonts(12)
		bind $w.f_$var.e_$var <Button-3> "help_box \"$label\"" 

		bind $w.f_$var.e_$var <Key> {set save_flag $need_save}
		
		pack $w.f_$var.e_$var -side left -fill x -expand true -padx 3
		
		
		# these are the bindings that cause the automatic updating
		# in the main lists from these three fields
		#
		if { ($var == "name") || \
			($var == "ref_name") || \
			($var == "comment") || \
			($var == "jump_name") } {
		    bind $w.f_$var.e_$var <KeyRelease> \
			    "refresh_item_named $name"
		    bind $w.f_$var.e_$var <FocusIn> \
			    "refresh_item_named $name"
		    bind $w.f_$var.e_$var <FocusOut> \
			    "refresh_item_named $name"
		    bind $w.f_$var.e_$var <Leave> \
			    "refresh_item_named $name"
		    bind $w.f_$var.e_$var <Enter> \
			    "refresh_item_named $name"
		}
		    
	    } else {
		set size_val [llength $param]
		frame $w.f_$var.vals
		pack $w.f_$var.vals -side left
		set b_frame $w.f_$var.vals_0 
		set b_length 0
		frame $b_frame 
		pack $b_frame -side top -anchor nw -fill y -expand true
		for {set j 4} {$j < $size_val} {incr j} {
		    set val [lindex $param $j]
		    incr b_length [string length $val]
		    incr b_length 3
		    if { $b_length > $entry_length } {
			set b_length 0
			incr b_length [string length $val]
			incr b_length 3
			set b_frame [format "%s_0" $b_frame ]
			frame $b_frame
			pack $b_frame -side top  \
				-anchor nw -fill y -expand true
		    }
		    
		    if { [catch { set temp $vars($name,$var) } ] != 0 } {
			set vars($name,$var) [lindex $param 3]	    
		    }
		    radiobutton $b_frame.r_$val -text $val -value $val \
			    -variable vars($name,$var) -font $fonts(12)
		    bind $b_frame.r_$val <Button-3> "help_box \"$label\"" 

		    bind $b_frame.r_$val <Button-1> {
			set save_flag $need_save
		    }
		    pack $b_frame.r_$val -side left \
			    -anchor w
		}
	    }
	}
	plot
	button $w.dismiss -command "plot; destroy $w" -text \
		"close window" -pady 0 -font $fonts(14)
	pack $w.dismiss -side top -fill x
    }
}

# end of file
#
