# file: lk_get_list.tcl
#
# This proc creates the generic list that will be used by make_it_list
# to create the list that will be used by display_list to create the
# configuration widget for each item #
#
proc get_list { type } {
    global items_defs
    global item_params
    
    if { $type == "" } {

	# should never be here
	#

	error_window "internal error" \
		"Bad type set"
	puts $get_list_error
	return {}
    } else {

	# match on the item type
	#
	foreach item_def $items_defs {
	    
	    if { "$type" == [lindex $item_def 0] } {

		# configure template list for this type
		#
		set params [lindex $item_def 1]
		foreach param $params {

		    # description is a main advantage to this system
		    # different items can use different parameters in 
		    # different ways, this description makes this easy
		    # to visualize and maintain.
		    #
		    set pname [lindex $param 0]
		    set desc [lindex $param 1]
		    
		    foreach it_param $item_params {
			if { "$pname" == [lindex $it_param 0] } {
			    if { "$pname" == "type" } {
				set temp_list [ list $pname $desc  \
					[lindex $it_param 2] \
					[lindex $it_param 3] \
					$type ]
				lappend it_list $temp_list
			    } else {
				lappend it_list [lreplace $it_param 1 1 $desc]
			    }
			}
		    }
		}
		break
	    }
	}	
	return $it_list
    }

    # error
    #
    puts $get_list_error
}

# end of file
#
