# file: lk_globals.tcl
#

# this is the name of the executable external help program
#
global help_prog_name
set help_prog_name "$env(LINKON)/bin/$env(ISIP_BINARY)/lk_help"

# this is the two dimensional associative array that holds all
# variable settings
#
global vars

# These variables deal with keeping track of whether changes have been
# made to the parameter settings. If save_flag is set to $need_save,
# then changes have been made and saving is necessary. If save_flag is
# set to $no_save, then no changes have been made and saving is not
# necessary.
#
global save_flag
global need_save 
global no_save
global cur_saving
set need_save "**"
set no_save "--"
set save_flag $no_save
set cur_saving 0

# these are two global values needed for the multiple listboxes
global LB_W
global LB_lboxes

# this is the number of characters wide each entry widget is made
#
global entry_length
set entry_length 60

# this is the length (number of characters) allowed for the number of items
#
global len_nitems
set len_nitems 3

# this is the height of the canvas
#
global canv_height
set canv_height 250

# this is the current number of items in the list
#
global num_items
set num_items 0

# this is the total number of items ever edited by the app
#
global num_items_hist
set num_items_hist 0

# this is the current item number selected in the listboxes. it will be 
# the target of any cut operations, and any insert operations will use this
# number as a reference (inserting either before or after)
#
global item_number
set item_number 0

# this holds a list of the names of the items currently defined, and
# not deleted, in order 
#
global item_list
set item_list {}

# see data.tcl for descriptions of these variables
#
global general_params


# this is the direction that the new items will be inserted.
#   if this is set to 0, the new item will be inserted before item_number
#   if this is set to 1, the new item will be inserted after item_number
#
global insert_dir
set insert_dir 1

# this is a list of all items that have been deleted, or cut.
#
global deleted_list
set deleted_list {}

# this is the string that begins the dcol file format
#
global magic_string
set magic_string "Data collect parameter file"

# this is the string that is placed in the parameter file to separate items
#
global item_delimiter
set item_delimiter "ITEM;"

# define the graphics directory
#
global graphics_dir
set graphics_dir "$env(LINKON)/lib/graphics"

# this is the graphic file (bitmap) that contains the graphic question mark
# used in the help window layout
#
global question_graphic
set question_graphic "$graphics_dir/help.gif"

# this is the default graphic icon file (bitmap) that is displayed besides
# each item parameter in the listing if one is not specified.
#
global default_graphic 
set default_graphic "tele.xbm"

global default_plot_graphic
set default_plot_graphic "play.gif"

global default_print_graphic
set default_plot_graphic "play.xbm"

global plot_images_gif
global plot_images_xbm

set plot_images_gif gif
set plot_images_xbm xbm

# this is the filename currently being operated upon.
#
global filename
set filename $argv

# set up the names for the multiple listboxes in the control window
#

# define the array label names for the listboxes
set item_boxes { it_num it_pnuem it_type it_name it_ref_name it_jump_name}

# define each actual name to be displayed on the screen
#
global title_name
set title_name(it_num) "num"
set title_name(it_pnuem) "abbrev"
set title_name(it_name) "name of item"
set title_name(it_type) "type of item"
set title_name(it_ref_name) "referenced item"
set title_name(it_jump_name) "jump to on abort"

# used by debug mode
#
set title_name(it_ref_dtmf) "referenced DTMF"
set title_name(it_cur_dtmf) "current DTMF"

# define some vars used in drawing
#
global ditem_height
global ditem_width
global ditem_sep
global draw_list
global last_number 0
global max_ref_height max_jump_height

set max_ref_height 0
set max_jump_height 0
set draw_list {}
set ditem_height 120
set ditem_width 73
set ditem_sep 30

# define some fonts to be used
#
global fonts
global font_list

set fonts(6) "-misc-fixed-medium-r-normal-*-*-60-*-*-c-*-iso8859-*"
set fonts(10) "*-times-medium-r-normal--*-100-*"
set fonts(12) "*-times-bold-r-normal--*-120-*"
set fonts(14) "*-times-bold-r-normal--*-140-*"

set font_list($fonts(6)) {Misc 6}
set font_list($fonts(10)) {Times 10}
set font_list($fonts(12)) {Times-Bold 12}
set font_list($fonts(14)) {Times-Bold 14}

# used in printing
#
global p_filename
global p_command
global p_name
global p_use_filename
global p_npages

set p_filename "/tmp/lk_[pid].ps"
set p_use_filename 0
set p_name "rose"
set p_command "/u0/duncan/bin/rlpr -P"
set p_npages 5

# paper width, height, vertical margin, horiz margin
#
global p_width
global p_height
global p_vmargin
global p_hmargin

set p_width 10i
set p_height 7.5i
set p_vmargin 0.5i
set p_hmargin 0.5i

# use a range, range begin and end
#
global p_range
global p_rbegin
global p_rend

set p_range 0
set p_rbegin 1
set p_rend 1

# used for progress update
#
global prog_fp progress_file prog_w

set prog_fp ""
set progress_file ""
set progress_w ""

global prog_spknum prog_cur_dtmf prog_ref_dtmf prog_boxes
global lb_cur_dtmf lb_ref_dtmf

set prog_spknum -1
set prog_cur_dtmf ""
set prog_ref_dtmf ""
set prog_boxes {it_cur_dtmf it_ref_dtmf}

# end of file
#
