# file: lk_load_file.tcl
#
# This proc loads in a pre-existing configuration file to be edited.
#

proc load_file { fp } {
    
    global magic_string
    global vars
    global item_delimiter
    global item_boxes
    global LB_W
    global item_number
    global item_list
    global general_params
    global num_items
    global num_items_hist
    global item_params
    global save_flag
    global no_save

    # first clear out the old one
    #
    new_app

    # check for the magic string
    #
    set line [gets $fp]
    
    if { $line != $magic_string } {
	error_window "bad file format" \
		"The given file was not a valid parameter file"
    } else {

	# initialize so we only read into general parameters at the
	# begining
	#
	set general 0
	
	while { ! [eof $fp] } {
	 
	    # read in the next line
	    #
	    set line [gets $fp]
	    if {$line != ""} {
		
		if {[string range $line 0 0] != "#"} {
		    
		    # parse non-null, non comment lines
		    #

		    if {$line == $item_delimiter} {
			set general 1
			incr item_number
			incr num_items
			incr num_items_hist
			lappend item_list it_$item_number
#			update idletasks
		    } else {
			
			# parse the line into a name value pair
			#
			scan $line "\%s\%\*s\%\[\^\;\]" name value
			
			set value [string trim $value]
			set value [string trim $value \"]

			# set the parameter to the value
			#
			if {$general == 0} {
			    set vars(general,$name) $value
			} else {
			    set vars(it_$item_number,$name) $value
			}
		    }
		} else {
		    
		    # check for the specific comment to be kept with
		    # the system
		    #
		    if {[string range $line 0 2] == "#* "} {
			set value [string range $line 3 end]
			if {$general == 0} {
			    set vars(general,comment) $value
			} else {
			    set vars(it_$item_number,comment) $value
			}
		    }
		}
	    }
	}

	# loop through items and set default parameters
	#
	foreach item $item_list {
	    set it_type ""
	    catch { set it_type $vars($item,type) }
	    if [string match $it_type ""] {
		error_window "internal error" "Bad Type Set"
		puts $load_file_error
	    } else {
		foreach entry [get_list $it_type] {
		    set param [lindex $entry 0]

		    if { [catch { set temp $vars($item,$param) } ] != 0 } {
			set vars($item,$param) [lindex $entry 3]	    
		    }
		}
	    }
	}
	    

	# set up the listbox display
	#
	for {set i 1} {$i <= [llength $item_list]} {incr i} {

	    # first set the number
	    #
	    $LB_W.it_num insert [expr $i-1] [expr $i+0]

	    # initialize the values
	    #
	    set type ""
	    set it_type ""
	    set name ""
	    set ref_name ""
	    set jump_name ""

	    # try to read the values from memory
	    #
	    set it_type $vars(it_$i,type)
	    catch {set name $vars(it_$i,name)}
	    catch {set ref_name $vars(it_$i,ref_name)}
	    catch {set jump_name $vars(it_$i,jump_name)}

	    # set the listboxes
	    #
	    $LB_W.it_type insert [expr $i-1] $it_type
	    $LB_W.it_pnuem insert [expr $i-1] [get_pnuem "$it_type"]
	    $LB_W.it_name insert [expr $i-1] $name
	    $LB_W.it_ref_name insert [expr $i-1] $ref_name
	    $LB_W.it_jump_name insert [expr $i-1] $jump_name    
	    
	    if {[expr $i % 17] == 0} {
		update idletasks
	    }
	}
	set save_flag $no_save
	plot
    }
}

# end of file
#

