# file: lk_menu.tcl
#
# This proc generates the pull down menus
#
proc gen_menu menu_widget {

    global item_params
    global save_flag
    global need_save
    global PNUEM
    global fonts
    global LK_HOME
    global p

    # a global variable is used here because event evaluation can be
    # tricky
    #
    global mw
    set mw $menu_widget

    
    # define what's in the menu bar frame
    #
    menubutton $mw.file -text File -underline 0 -menu $mw.file.menu \
	    -font $fonts(14)
    menubutton $mw.insert -text "Item" -underline 0 -menu $mw.insert.menu \
	    -font $fonts(14)
    menubutton $mw.edit -text Edit -underline 0 -menu $mw.edit.menu \
	    -font $fonts(14)
    menubutton $mw.config -text Configure -underline 0 -menu $mw.config.menu \
	    -font $fonts(14)
    menubutton $mw.util -text Util -underline 0 -menu $mw.util.menu \
	    -font $fonts(14)
    menubutton $mw.help -text Help -underline 0 -menu $mw.help.menu \
	    -font $fonts(14)

    pack $mw.file $mw.insert $mw.edit $mw.config $mw.util -side left
    pack $mw.help -side right

    
    # define the help menu
    #
    menu $mw.help.menu -font $fonts(12)
    menu $mw.help.menu.items -font $fonts(12)

    bind $mw.help <Button-3> { help_box help }
    
    $mw.help.menu add command -label "General" -command {help_box "general"}

    $mw.help.menu add command -label "Starting out" \
	    -command {help_box "starting out"}
    $mw.help.menu add command -label "Key Bindings" \
	    -command {help_box "key bindings"}
    $mw.help.menu add cascade -label Items -menu $mw.help.menu.items
    


    # define the insert menu - from which new items are inserted
    #
    menu $mw.insert.menu -font $fonts(12)
    
    set temp [lindex $item_params 0]
    set item_types [lrange $temp 4 end]
    foreach item $item_types {
	set pnuem [get_pnuem "$item"]
	set name "$pnuem: $item"
	$mw.insert.menu add command -label $name \
		-command "insert_item \"$item\"; set save_flag $need_save"
    }

    # cascade help on each item type
    #
    $mw.insert.menu add cascade -underline 0 \
	    -label "Help on item type" \
	    -menu $mw.insert.menu.help -font $fonts(12)
    
    menu $mw.insert.menu.help -font $fonts(12)
    foreach item $item_types {
	set pnuem [get_pnuem "$item"]
	set name "$pnuem: $item"
	$mw.insert.menu.help add command -label $name \
		-command "help_box \"$item\""
	$mw.help.menu.items add command -label $name \
		-command "help_box \"$item\""
    }
    
    # make an attempt at placing a help menu on the right mouse button
    # press. Not very pretty but it works.
    #
    bind $mw.insert <Button-3> {
	$mw.insert.menu.help post [expr %x-20] [expr %y+10]
	bind $mw.insert.menu.help <Leave> {
	    $mw.insert.menu.help unpost
	}
    }


    # define the file menu
    #
    menu $mw.file.menu -font $fonts(12)
    bind $mw.file <Button-3> { help_box "file menu" }
	

    # define the new action, which clears the current application
    #
    $mw.file.menu add command -label "New"  -underline 0 -command { 
	confirm_window New "Clear application: Are you sure?" new_app
    }
    
    # define the open action, which loads a data collection file
    #
    $mw.file.menu add command -label "Open" -underline 0 \
	    -accelerator "ctrl-o" -command { 
	
	confirm_window Load "Clear current Application" open_application
	
    }
    
    bind $p <Control-o> {
	confirm_window Load "Clear current Application" open_application
    }
    
    $mw.file.menu add command -label "Save" -underline 0 \
	    -command save_proc -accelerator "ctrl-s"
    
    bind $p <Control-s> save_proc
    
    proc save_proc {} {
	global filename
	global cur_saving
	
	if {$cur_saving == 0} {
	    set cur_saving 1
	    if {$filename != "" } {
		set fp [open $filename "w"]
		save_all $fp
		close $fp
	    } else {
		error_window "invalid filename" \
			"There is no valid filename to save to, try Save As"
	    }
	    set cur_saving 0
	}
    }
    $mw.file.menu add command -label "Save As" -underline 5 -command {
	set file [tk_filesel .filesel -filemask "*.dcol" \
		-directory [file dirname $filename]]
	
	if { $file != "" } {
	    set filename $file
	    set fp [open $filename "w"]
	    save_all $fp
	    close $fp
	}
    }

    $mw.file.menu add command -label "Revert" -underline 1 -command {
	confirm_window Revert "Revert to saved" revert_proc
    } -accelerator "ctrl-r"

    bind $p <Control-r> {
	confirm_window Revert "Revert to saved" revert_proc
    }
    proc revert_proc {} {
	new_app
	open_application_filename
    }
    
    $mw.file.menu add command -label "Print" -underline 0 \
	    -command print_proc -accelerator "ctrl-p"
    bind $p <Control-p> print_proc
    $mw.file.menu add separator
    $mw.file.menu add command -label "New Window" -underline 4 -command \
	    { exec $env(LINKON)/bin/$env(ISIP_BINARY)/lk_appbuilder & }
    
    $mw.file.menu add command -label "Close Window" -underline 0 \
	    -command { exit_cc } -accelerator "ctrl-q"
    bind $p <Control-q> exit_cc


    # define the edit menu
    #
    menu $mw.edit.menu -font $fonts(12)

    bind $mw.edit <Button-3> { help_box "edit menu" }
    
    $mw.edit.menu add command -label "Cut" -underline 0 \
	    -command {delete_item} -accelerator "C-x"
    $mw.edit.menu add command -label "Copy" -underline 1 \
	    -command {copy_item} -accelerator "C-c"
    $mw.edit.menu add command -label "Paste" -underline 0 \
	    -command {re_insert_item} -accelerator "C-v"
    $mw.edit.menu add command -label "Delete" -underline 0 \
	    -command {kill_item} -accelerator "C-d"
    $mw.edit.menu add separator
    $mw.edit.menu add cascade -label "Insert direction" -underline 0 \
	    -menu $mw.edit.menu.dir


    # define the cascaded insertion direction menu
    #
    menu $mw.edit.menu.dir -font $fonts(12)
    
    $mw.edit.menu.dir add radiobutton -variable insert_dir \
	    -label before -value 0 -underline 0
    $mw.edit.menu.dir add radiobutton -variable insert_dir \
	    -label after -value 1 -underline 0 
    
    # define the configure menu
    #
    menu $mw.config.menu -font $fonts(12)
    
    bind $mw.config <Button-3> { help_box "configuration menu" }

    $mw.config.menu add command -label "General Parameters" \
	    -underline 0 -command {
	display_list $general_params general "General Parameters"
    } 
    
    $mw.config.menu add command -label "Configure Item" \
	    -underline 0 -command {
	view_item $item_number
    }

    # define the util menu
    #
    menu $mw.util.menu -font $fonts(12)
    
    bind $mw.util <Button-3> { help_box "util menu" }

    $mw.util.menu add command -label "Run Debugger" \
	    -underline 0 -command progress
    
    bind $p <Return> { view_item $item_number}
}


proc confirm_window {title text command} {

    global save_flag need_save fonts

    if {$save_flag == $need_save } {
	set new_wid ".new"
	
	if { [winfo exists $new_wid] != 0 } {
	    wm deiconify $new_wid
	    
	    raise $new_wid
	    
	    $new_wid.cancel takefocus
	} else {
	    toplevel $new_wid
	    
	    wm geometry $new_wid +400+400
	    wm title $new_wid "$title: confirm"
	    
	    message $new_wid.msg -text $text \
		    -width 200 \
		    -padx 20 -pady 20 -font $fonts(10)
	    
	    button $new_wid.quit -text $title \
		    -command "$command; destroy $new_wid" \
		    -font $fonts(14)
	    button $new_wid.cancel -text "Cancel" \
		    -command "destroy $new_wid" \
		    -font $fonts(14)
	    
	    pack $new_wid.msg
	    pack $new_wid.quit $new_wid.cancel \
		    -side left -fill both -expand true
	}
	
    } else {
	eval $command
    }
}

proc open_application_filename {} {
    global filename
    if { $filename != "" } {
	set fp [open $filename "r"]
	load_file $fp
	close $fp
    }
}
proc open_application {} {

    global filename
    set file [tk_filesel .filesel -defaultfile $filename \
	    -filemask "*.dcol" \
	    -directory [file dirname $filename]]
    
    if { $file != "" } {
	set filename $file
	open_application_filename
    }
}

# end of file
#





