# file: lk_plot.tcl
#
# This proc creates the list that is used to plot the call flow
#

proc plot {} {
    global item_list
    global vars
    global draw_list
    global num_items

    # push the old draw list
    #
    set old_draw_list $draw_list
    set draw_list {}

    # create the new draw list
    #
    set i 0
    foreach item $item_list {

	# initialize values
	#
	set it_name ""
	set it_refname ""
	set it_jumpname ""
	set it_type ""
	set jump_num ""
	set ref_num ""
	set chan ""

	incr i +1

	# test for unique names through the system
	#
	catch {
	    set it_name $vars($item,name) 
	    if {$it_name != ""} {
		foreach test_item $item_list {
		    if {[string match $item $test_item] == 0} {
			catch {
			    set it_test_name $vars($test_item,name)
			    if [string match $it_test_name $it_name] {
				error_window "duplicate item name" \
					"The name '$it_name' is not unique"
				
			    }
			}
		    }
		}
	    }
	}
	    
	catch {
	    set it_jumpname $vars($item,jump_name) 

	    
	    # jump will be replaced by an item number, find it
	    #
	    if {$it_jumpname != ""} {
		set jump_num [expr [get_named_it_num $it_jumpname]+1]
		
		if {$jump_num == 0 } {
		    error_window "invalid jump item" \
			    "The item '$it_jumpname' referenced in item $i is not presently in the system"
		    set jump_num ""
		}
	    }
	}

	catch {
	    set it_refname $vars($item,ref_name) 

	    # reference will be replaced by an item number, find it
	    #
	    if {$it_refname != ""} {
		set ref_num [expr [get_named_it_num $it_refname]+1]

		if {$ref_num == 0 } {
		    error_window "invalid referenced item" \
			    "The item '$it_refname' referenced in item $i is not presently in the system"
		    set ref_num ""
		}
	    }
	}

	catch {set it_type $vars($item,type) }

	catch {
	    set chan $vars($item,conf_channel) 

	    if { $chan == "slave" } {
		set chan "S"
	    } elseif { $chan == "both" } {
		set chan "B"
	    } else {
		set chan "M"
	    }
	}
	
	# set the next, should be non null for all but last entry
	#
	set next [expr $i +1]
	if {$next > $num_items} {
	    set next ""
	}
	
	# append to list
	#
	set tlist {}
	set tlist [linsert $tlist 0 "$it_type" "$it_name" \
		"$next" "$jump_num" "$ref_num" "$chan"]
	if {$it_type == ""} {puts "tlist($i) ($item) = $tlist"}
	set draw_list [linsert $draw_list end $tlist]
    }
    
    # only plot if the list has changed, great timesaver
    #
    if {$draw_list != $old_draw_list} {
	plot_list
    }
}


# end of file
#
