#! /usr/local/tk/bin/wish -f
# file: lk_plot_list.tcl
#
# this procedure draws the plot of the current call flow
#
# it uses the global variable draw_list, which is a list of sets
#  { {item type}  {name of item} {next_number} {jump number} {ref number}}
#
proc plot_list {} {
    
    global p
    global plot_images_gif 
    global plot_images_xbm
    
    plot_list_w "$p.display_f.canvas" $plot_images_gif

}
proc plot_list_w { w image_type } {
    
    global images p_images
    global ditem_height
    global ditem_width
    global ditem_sep
    global draw_list
    global items_defs
    global num_items
    global default_plot_graphic
    global graphics_dir
    global fonts
    global plot_images_gif
    global plot_images_xbm
    global max_ref_height max_jump_height
    global plot_ref_arrows plot_jmp_arrows
    
    set plot_ref_arrows {}
    set plot_jmp_arrows {}
    set max_ref_height 0
    set max_jump_height 0

    set half_width [expr $ditem_width /2]
    set image_height 73
    set y_offset 50
    set x_offset 20

    set mid_y [expr $y_offset + ($image_height/2) +2]
    
    # delete everthing to start out with
    #
    $w delete all

    for {set i 1} {$i <= $num_items} {incr i} {
	set top_enter($i) 0
	set bot_enter($i) 0
	for {set j 1} {$j <= $num_items} {incr j} {
	    set top_matrix($i,$j) 0
	    set bot_matrix($i,$j) 0
	}
    }

    # first, create simple explanation tags
    #
    $w create text -20 [expr $y_offset -20] -text "Control Flow" \
	    -font $fonts(10) -tags "control_flow control_flow_label"

    $w create text -20 [expr $y_offset + $ditem_height + 20] \
	    -text "Data Flow" -font $fonts(10) \
	    -tags "data_flow data_flow_label"
    
    $w bind "control_flow" <ButtonRelease-3> "help_box \"control flow\""
    $w bind "data_flow" <ButtonRelease-3> "help_box \"data flow\""

    $w bind "control_flow_label" <ButtonRelease-1> "help_box \"control flow\""
    $w bind "data_flow_label" <ButtonRelease-1> "help_box \"data flow\""

    $w bind "plot_item_name" <ButtonRelease-3> "help_box \"name of item\""
    $w bind "plot_item_num" <ButtonRelease-3> "help_box \"item number\""
    $w bind "plot_item_chan" <ButtonRelease-3> "help_box \"conference\""

    # draw the draw_list
    #
    set i 0
    foreach item $draw_list {
	incr i +1

	if {[expr $i % 5] == 0} {
	    update idletasks
	}
	set ref_arrows {}
	set jmp_arrows {}
	
	# determine the outer dimensions of this item
	#
	set x0 [expr ($ditem_sep+$ditem_width)*($i -1) + $x_offset]
	set x1 [expr ($ditem_sep+$ditem_width)*$i -$ditem_sep + $x_offset]
	set y0 $y_offset
	set y1 [expr $y_offset + $ditem_height]

	# draw a clear box that will help out the scrollregion placement
	#
	$w create line $x0 $y0 $x0 $y1 $x1 $y1 $x1 $y0 $x0 $y0 -fill "" \
		-tags "item_$i"

	# draw the conventional arrow to the next item
	#
	set next [lindex $item 2]
	if {$next != ""} {
	    set ax0 $x1
	    set ax1 [expr $x1 + $ditem_sep]
	    
	    $w create line $ax0 $mid_y $ax1 $mid_y -width 5 -arrow last \
		    -tags "arrows_0"
	}

	$w bind "arrows_0" <ButtonRelease-3> { 
	    help_box "normal control flow"
	}
	
	# encorporate the item type into the graphic both by loading
	# the correct bitmap file and by displaying the text for the
	# item type
	#
	set it_type [lindex $item 0]
	if {$it_type == "" } {
	    puts "internal error"
	}
	set pnuem [get_pnuem "$it_type"]

	if {$image_type == $plot_images_gif} {
	    $w create image [expr $x0+$half_width] [expr $y0] \
		    -image images($pnuem) -anchor n \
		    -tags "item_$i item_type_$pnuem" 
	} elseif {$image_type == $plot_images_xbm} {
	    $w create bitmap [expr $x0+$half_width] [expr $y0] \
		    -tags "item_$i item_type_$pnuem" \
		    -bitmap "@$p_images($pnuem)" \
		    -anchor n
	    
	} else {
	    puts "Invalid image type requested"
	}
	    
	# display the item's name, if it has one
	#
	$w create text [expr $x0 + [expr $ditem_width/2]] \
		[expr $y0 + $image_height] -anchor n \
		-text [lindex $item 1] \
		-justify center \
		-width [expr $ditem_width-5] \
		-font $fonts(14) \
		-tags "item_$i plot_item_name"
	

	# display the item's number in a little circle to the nw
	#

	$w create arc [expr $x0 ] [expr $y0 -9] [expr $x0 +22] $y0 \
		-extent 359.99999 -style arc -tags "item_$i plot_item_num" \
		-fill White 

	$w create text [expr $x0 + 11 ] \
		[expr $y0 - 4] \
		-text $i \
		-anchor c \
		-justify center \
		-width 15 \
		-font $fonts(6) \
		-tags "item_$i plot_item_num"

	# setup the channel display in the upper right corner
	#
	set chan [lindex $item 5]
	
	$w create text [expr $x0 + 8 ] \
		[expr $y0 + 6] -anchor c \
		-text $chan \
		-justify center \
		-width 10 \
		-font $fonts(10) \
		-tags "item_$i plot_item_chan"
	
	# setup the keybindings for this item -- same as in listbox
	# specifically: highlight the number on the boxes
	#
	$w bind "item_$i" <Button-1> "LBviewit $i"
	$w bind "item_$i" <Double-Button-1> "view_item $i"
	
	# now worry about the control abort arrows
	#
	# in order to do this, a nxn matrix is kept  (where n is num_items)
	# and every time that a arrow is drawn the matrix is updated for
	# every place on the matrix it passes, each arrow being 1
	# space higher int the matrix than the last
	#

	set jump_num [lindex $item 3]
	
	if {$jump_num != ""} {
	    set arrow_beg_x $i
	    set arrow_end_x $jump_num
	    
	    if {$arrow_beg_x != $arrow_end_x} {
		
		if {$arrow_beg_x > $arrow_end_x} {
		    set temp $arrow_beg_x
		    set arrow_beg_x $arrow_end_x
		    set arrow_end_x $temp
		}
		set num_inrow 1
		set short 0
		if {[expr abs($arrow_beg_x - $arrow_end_x)] <= 3} {
		    set sj 1
		} else {
		    if {$num_items >= 2} {
			set sj 2
		    } else {
			set sj 1
		    }
		}
		for {set j $sj} {$num_inrow != 0} {incr j} {

		    set num_inrow 0
		    if {$top_matrix($i,$j) == $jump_num} {
			set short 1
		    } else {
			for {set k $arrow_beg_x} \
				{$k < $arrow_end_x} {incr k} {
			    incr num_inrow $top_matrix($k,$j)
			}
		    }
		}
		incr j -1
		
		if {$arrow_end_x < $num_items} {
		    incr arrow_end_x +1
		}

		# j now holds the row number the line will ride over, 
		# so set the matrix accordingly
		#
		if {$short == 0} {
		    for {set k $arrow_beg_x} {$k < $arrow_end_x} {incr k} {
			set top_matrix($k,$j) $jump_num
		    }
		}
		
	    } else {
		set j 0
		set top_matrix($i,$j) $jump_num
	    }
	    
	    # now we now the height it should rise to, draw the line
	    #
	    set ax0 [expr $x0 + ($ditem_width/2)] 
	    set ax1 [expr ($jump_num-1) * ($ditem_width + $ditem_sep)]
	    if {$short == 0} {
		incr top_enter($jump_num)
	    }
	    set ax1 [expr $ax1 + ($ditem_width/8) - $top_enter($jump_num)*3]
	    set height [expr $y_offset - $j*5- 20]
	    
	    if {$height < $max_jump_height} {
		set max_jump_height $height
		# puts "new max jump height ($i) -> $height"
	    }

	    set jmp_arrows "line $ax0 $y_offset $ax0 $height \
		    $ax1 $height $ax1 [expr $y_offset + ($image_height/2)] \
		    -arrow last"
	    lappend plot_jmp_arrows $jmp_arrows
	    if {$short == 0} {
		eval "$w create $jmp_arrows -tags \"control_flow cflow_$i\""
	    } else {
		set rise "$ax0 $y_offset $ax0 [expr $height + 2]"
		if {$jump_num > $i} {
		    set run +20
		} else {
		    set run -20
		}
		set curve "$ax0 [expr $height + 2] [expr $ax0 + $run] \
			$height"
		eval "$w create line $rise $curve  \
			-tags \"control_flow cflow_$i\""
	    }
	    $w bind "cflow_$i" <Button-2> "LBviewit $jump_num"	    
	    $w bind "cflow_$i" <Button-1> "LBviewit $i"	    
	    
	} else {
	    lappend plot_jmp_arrows {}
	}

	# now worry about the data referencing arrows
	#
	# in order to do this, a nxn matrix is kept  (where n is num_items)
	# and every time that a arrow is drawn the matrix is updated for
	# every place on the matrix it passes, each arrow being 1 higher than
	# the last
	#
	set ref_num [lindex $item 4]
	
	if {$ref_num != ""} {
	    set arrow_beg_x $i
	    set arrow_end_x $ref_num
	    
	    if {$arrow_beg_x != $arrow_end_x} {
		
		if {$arrow_beg_x > $arrow_end_x} {
		    set temp $arrow_beg_x
		    set arrow_beg_x $arrow_end_x
		    set arrow_end_x $temp
		}
		set num_inrow 1
		for {set j 1} {$num_inrow != 0} {incr j} {
		    set num_inrow 0
		    for {set k $arrow_beg_x} {$k < $arrow_end_x} {incr k} {
			incr num_inrow $bot_matrix($k,$j)
		    }
		}
		incr j -1
		# j now holds the row number the line will ride over, 
		# so set the matrix accordingly
		#
		for {set k $arrow_beg_x} {$k < $arrow_end_x} {incr k} {
		    set bot_matrix($k,$j) 1
		}

	    } else {
		
		for {set j 1} {$bot_matrix($i,$j) != 0} {} {incr j}
		
		set bot_matrix($i,$j) 1
		set ref_num $i
	    }
	    
	    # now we now the height it should rise to, draw the line
	    #
	    set ax0 [expr $x0 + $ditem_width/2]
	    set ax1 [expr $ref_num * ($ditem_width + $ditem_sep)]
	    incr bot_enter($ref_num)
	    set ax1 [expr $ax1 + $bot_enter($ref_num)*3 - ($ditem_width/2)]

	    set height [expr $y_offset + $ditem_height + $j*5 + 20]
	    
	    if {$height > $max_ref_height} {
		set max_ref_height $height
#		puts "new max ref height ($i) -> $height"
	    }
	    
	    set ref_arrows "line $ax0 $y1 $ax0 $height \
		    $ax1 $height $ax1 $y1 \
		    -arrow first"

	    lappend plot_ref_arrows $ref_arrows

	    eval "$w create $ref_arrows -tags \"data_flow dflow_$i\""
	    $w bind "dflow_$i" <Button-2> "LBviewit $ref_num"
	    $w bind "dflow_$i" <Button-1> "LBviewit $i"
	    
	} else {
	    lappend plot_ref_arrows {}
	}
    }
    
    # reconfigure the scroll region to encompass the whole image
    #
    set size [$w bbox all]

    set x0 [lindex $size 0]
    set y0 [lindex $size 1]
    set x1 [lindex $size 2]
    set y1 [lindex $size 3]

    set x0 [expr $x0 - $x_offset]
    set x1 [expr $x1 + $x_offset]
    set y0 [expr $y0 - 5]


    set size {}
    set size [linsert $size 0 $x0 $y0 $x1 $y1]
    $w configure -scrollregion $size

}


# end of file
#


