# file: lk_print.tcl 

# This proc creates a user entry window for printing
#
proc print_proc {} {
    global p
    global p_filename
    global p_command
    global p_width
    global p_height
    global p_vmargin
    global p_hmargin
    global p_name
    global p_name
    global p_range
    global p_rbegin
    global p_rend
    global p_npages
    global w_prn

    set filename "/tmp/linkon_tmp.ps"
    set w_prn "$p.print_options"
    
    # if the window exists, re-use it
    #
    if { [winfo exists $w_prn] == 1} {
	wm deiconify $w_prn
	raise $w_prn
    } else {
	
	# create a new window
	#
	toplevel $w_prn
	
	wm title $w_prn "Print"
	
	# set up the frames for the general layout
	#
	frame $w_prn.head
	frame $w_prn.ranges
	frame $w_prn.range -relief ridge -borderwidth 1
	frame $w_prn.npages -relief ridge -borderwidth 1
	frame $w_prn.body
	frame $w_prn.printer 
	frame $w_prn.file
	frame $w_prn.foot

	pack $w_prn.head $w_prn.ranges $w_prn.body $w_prn.printer \
		$w_prn.file $w_prn.foot -side top \
		-fill both -expand true \
		-padx 5 -pady 5

	pack $w_prn.range $w_prn.npages -side left -in $w_prn.ranges \
		-pady 0 -padx 5 -expand true -fill both

	# set up the body - paper size and margins
	#
	frame $w_prn.paper_size -border 1 -relief ridge
	frame $w_prn.margins -border 1 -relief ridge

	label $w_prn.head.title -text "Print"
	pack $w_prn.head.title -anchor w

	pack $w_prn.paper_size $w_prn.margins -in $w_prn.body \
		-side left -fill both -padx 5 -expand true

	label $w_prn.paper_size.lab -text "Printer Paper size:"
	label $w_prn.margins.lab -text "Printer Margins:"

	frame $w_prn.paper_size.w
	frame $w_prn.paper_size.h
	frame $w_prn.margins.v
	frame $w_prn.margins.h
	
	pack $w_prn.paper_size.lab -side top -anchor w
	pack $w_prn.paper_size.w $w_prn.paper_size.h -side top \
		-fill both -expand true

	pack $w_prn.margins.lab -side top -anchor w
	pack $w_prn.margins.v $w_prn.margins.h -side top \
		-fill both -expand true
	
	
	# set up all the range information
	#
	label $w_prn.lrange -text "Print Range:"
	radiobutton $w_prn.range_no -variable p_range -value 0 -text "All"
	radiobutton $w_prn.range_yes -variable p_range -value 1 -text ""


	label $w_prn.lsrange -text "Start Item:"
	label $w_prn.lerange -text "End Item:"

	entry $w_prn.esrange -textvariable p_rbegin -width 5
	entry $w_prn.eerange -textvariable p_rend -width 5

	pack $w_prn.lrange $w_prn.range_no $w_prn.range_yes $w_prn.lsrange \
		$w_prn.esrange $w_prn.lerange $w_prn.eerange -side left \
		-expand true -fill both -in $w_prn.range
	
	label $w_prn.lnpages -text "Pages:"
	entry $w_prn.enpages -textvariable p_npages -width 5
	
	pack $w_prn.lnpages $w_prn.enpages -in $w_prn.npages -side left \
		-expand true -fill both -pady 0

	# set up the page size
	#
	label $w_prn.l_psize_w -text "Width: "
	label $w_prn.l_psize_h -text "Height:"

	entry $w_prn.e_psize_w -textvariable p_width
	entry $w_prn.e_psize_h -textvariable p_height

	pack $w_prn.l_psize_w -side left \
		-in $w_prn.paper_size.w -padx 6
	pack $w_prn.e_psize_w -side right -fill both -expand true \
		-in $w_prn.paper_size.w
	pack $w_prn.l_psize_h -side left \
		-in $w_prn.paper_size.h -padx 6
	pack $w_prn.e_psize_h -side right -fill both -expand true \
		-in $w_prn.paper_size.h


	# set up the page margins
	#
	label $w_prn.l_margins_v -text "Vertical:  "
	label $w_prn.l_margins_h -text "Horizontal:"

	entry $w_prn.e_margins_v -textvariable p_vmargin
	entry $w_prn.e_margins_h -textvariable p_hmargin

	pack $w_prn.l_margins_v -side left -in $w_prn.margins.v -padx 6
	pack $w_prn.e_margins_v -side right -fill both -expand true \
		-in $w_prn.margins.v

	pack $w_prn.l_margins_h -side left -in $w_prn.margins.h  -padx 6 
	pack $w_prn.e_margins_h -side right -fill both -expand true \
		-in $w_prn.margins.h

	# set up the print name/command 
	#
	radiobutton $w_prn.r_prn_no -variable p_use_filename -value 0 -width 1
	label $w_prn.l_pname -text "Printer Name:"
	label $w_prn.l_pcommand -text "   Print Command:"

	entry $w_prn.e_pname -textvariable p_name
	entry $w_prn.e_pcommand -textvariable p_command
	pack $w_prn.r_prn_no $w_prn.l_pname $w_prn.e_pname $w_prn.l_pcommand  \
		-side left -fill both -in $w_prn.printer
	pack  $w_prn.e_pcommand -side right -fill both -expand true -in $w_prn.printer
	

	# set up the printer file
	#
	radiobutton $w_prn.r_prn_yes -variable p_use_filename -value 1 -width 1
	label $w_prn.l_filename -text "Print only to File:"
	entry $w_prn.e_filename -textvariable p_filename

	pack $w_prn.r_prn_yes $w_prn.l_filename -side left -fill both -in $w_prn.file
	pack $w_prn.e_filename -side right -fill both -expand true -in $w_prn.file
	

	# print command button
	#
	button $w_prn.print -text Print -command {
	    if {$p_use_filename != 0} {
		print_ps $p_filename
	    } else {
		print_ps "|$p_command$p_name"
	    }
	}

	# print cancel button
	#
	button $w_prn.cancel -text Cancel -command "destroy $w_prn"
    
	pack $w_prn.print -side left -in $w_prn.foot
	pack $w_prn.cancel -side right -in $w_prn.foot
	
	
	# when you change the radio button values, disable the unusable
	# entry widgets
	#
	bind $w_prn.r_prn_no <Leave> p_disable_stuff

	bind $w_prn.r_prn_yes <Leave> p_disable_stuff
	bind $w_prn.range_yes <Leave> p_disable_stuff
	bind $w_prn.range_no <Leave> p_disable_stuff
	
	p_disable_stuff

    }
}

# This is used by the print_proc user window to update the display
# enable/disable status
#
proc p_disable_stuff {} {
    global w_prn p_use_filename p_range
    if {$p_use_filename == 0} {
	$w_prn.e_pname configure -state normal
	$w_prn.e_pcommand configure -state normal
	
	$w_prn.e_filename configure -state disabled
    } else {
	$w_prn.e_pname configure -state disabled
	$w_prn.e_pcommand configure -state disabled
	
	$w_prn.e_filename configure -state normal
    }
    if {$p_range == 0} {
	$w_prn.esrange configure -state disabled
	$w_prn.eerange configure -state disabled
    } else {
	$w_prn.esrange configure -state normal
	$w_prn.eerange configure -state normal
    }
}

# This procedure prints the current application

# TCL does not support the printing of gif images, so we have to re-plot
# the app with xbm's first, then go back
#
proc print_ps {filename} {
    
    global p
    global fonts font_list
    global plot_images_xbm 
    global plot_images_gif
    global num_items

    global p_width
    global p_height
    global p_vmargin
    global p_hmargin
    global p_npages
    global p_range
    global p_rbegin
    global p_rend

    global max_ref_height max_jump_height

    set w $p.display_f.canvas

    # re-plot the application using xbm's -> printable
    #
    plot_list_w $w $plot_images_xbm
    update

    if {$p_range == 0} {
	
	set begin 1
	set end $num_items
	
    } else {

	set begin $p_rbegin
	set end $p_rend
    }


    # open the file and print the ps header
    #
    set fp [open $filename "w"]
#    puts $fp "%!PS"

    set density [expr int(ceil(($end - $begin) / $p_npages))]
    
    set l_begin $begin
    set l_end $begin
    for {set i 1} {$i <= $p_npages} {incr i} {
	
	if {$i == $p_npages} {
	    set l_end $end
	} else {
	    incr l_end $density
	}
	puts "printing page $i \[items $l_begin - $l_end\]"
	
	set size [$w bbox item_$l_begin item_$l_end]

	set x0 [lindex $size 0]
	set y0 [lindex $size 1]
	set x1 [lindex $size 2]
	set y1 [lindex $size 3]
	
	set y0 $max_jump_height
	set y1 $max_ref_height
	incr x1 100


	# print the data
	#
	puts $fp [$w postscript \
	    -pageheight $p_height -pagewidth $p_width \
	    -pagex $p_hmargin -pagey $p_vmargin  \
	    -pageanchor nw -rotate true \
	    -fontmap font_list \
	    -height [expr $y1 - $y0] \
	    -width [expr $x1 - $x0] \
	    -x $x0 -y $y0 ]
	
	incr l_begin $density
    }
    
    close $fp

    # return the plot to normal
    #
    plot_list_w $w $plot_images_gif
    update
}

    
# end of file
#


