# file: lk_print_list.tcl
#
# This proc prints the list of items to fp, the core of the save routine.
#
proc print_list { fp param_list name } {

    global vars
    global item_params

    foreach param $param_list {
	set var [lindex $param 0]
	
	# comments are printed elsewhere
	#
	if { $var != "comment" } {
	    
	    # see if the variable has a value
	    #
	    set value ""
	    catch {set value "$vars($name,$var)"}
	    
	    # try to keep default values out of the file
	    #
	    set default ""
	    foreach iparam $item_params {
		if { "$var" == [lindex $iparam 0]} {
		    set default [lindex $iparam 3]
		}
	    }

	    # if the value is valid, print it
	    #
	    #
	    # the format of the comparisons below are to prevent TCL
	    # from representing a value internally as an integer, such
	    # as a phone number or pin number, since TCL cannot handle
	    # large numbers as anything but strings
	    #
	    if {
		("r$value" != "r") && 
		("r$value" != "rnot defined") && 
		("r$value" != "r$default") 
	    } {
		set value [string trim $value "\ " ]
		set desc [lindex $param 1]
		puts $fp ""
		puts $fp "# set the parameter: $desc"
		puts $fp "#"
		puts $fp "$var = \"$value\";"
	    }
	}
    }
    puts $fp ""
    puts $fp ""
}

# end of file
#
