# file: lk_progress.tcl
#
# This proc displays debugging progress graphically
#
proc progress {} {
    global item_list
    global vars num_items
    global progress_file
    global prog_w
    global prog_fp
    global prog_spknum prog_cur_dtmf prog_ref_dtmf
    global LB_W
    global item_boxes LB_lboxes title_name fonts
    global prog_boxes lb_cur_dtmf lb_ref_dtmf

    set relief sunken

    set progress_file ""
	
    catch {set progress_file $vars(general,progress_file)}


    if {[string match $progress_file ""] == 0} {
	set prog_w ".progress"
	set PROG_LB $prog_w.data
	if [winfo exists $prog_w] {

	    wm deiconify $prog_w
	    
	    raise $prog_w
	    
	    $prog_w.t.out delete 1.0 end
	} else {
	    toplevel $prog_w
	    
	    wm protocol $prog_w WM_DELETE_WINDOW {
		set LB_lboxes {}
		foreach lb $item_boxes {
		    lappend LB_lboxes "$LB_W.$lb"
		}
		destroy $prog_w
	    }

	    wm title $prog_w "Debugging Console"
	    wm geometry $prog_w -59+119

	    frame $prog_w.t -borderwidth 5 -relief flat
	    frame $prog_w.spknum  -borderwidth 5 -relief flat
	    frame $prog_w.dtmf  -borderwidth 5 -relief flat
	    frame $prog_w.rdtmf -borderwidth 5 -relief flat
	    
	    label $prog_w.spknum.l -text "Speaker Number:"
	    entry $prog_w.spknum.e -textvariable prog_spknum -state disabled \
		    -width 30
	    pack $prog_w.spknum.l -side left
	    pack $prog_w.spknum.e -side right -fill x -expand true

	    label $prog_w.dtmf.l -text "Current DTMF:  "
	    entry $prog_w.dtmf.e -textvariable prog_cur_dtmf -state disabled
	    pack $prog_w.dtmf.l -side left 
	    pack $prog_w.dtmf.e -side right -fill x -expand true

	    label $prog_w.rdtmf.l -text "Reference DTMF:"
	    entry $prog_w.rdtmf.e -textvariable prog_ref_dtmf -state disabled
	    pack $prog_w.rdtmf.l -side left
	    pack $prog_w.rdtmf.e -side right -fill x -expand true
	    
	    
	    text $prog_w.t.out -yscrollcommand "$prog_w.t.scroll set" \
		    -width 1 -height 10
	    scrollbar $prog_w.t.scroll -command "$prog_w.t.out yview"

	    button $prog_w.quit -text "end debugging" -command {
		catch { close $prog_fp }
		set prog_fp ""
	    }

	    pack $prog_w.quit -side bottom -fill x
	    pack $prog_w.spknum $prog_w.dtmf $prog_w.rdtmf\
		    $prog_w.t -side top -fill both -expand true
	    pack $prog_w.t.out -side left -fill both -expand true
	    pack $prog_w.t.scroll -side left -fill y
	    

	    # now set up the data lboxes
	    #

	    # define frames to encapsulate the area
	    #
	    frame $PROG_LB -relief $relief -border 3
	    pack $PROG_LB -side bottom -fill both -expand true
	    
	    foreach lb $prog_boxes {
		
		global title_name
		frame $PROG_LB.f_$lb -relief $relief -border 3
		
		listbox $PROG_LB.$lb -export no -selectmode browse \
			-yscrollcom LBscroll -font $fonts(12)
		label $PROG_LB.l_$lb -text $title_name($lb) -font $fonts(12)
		
		pack $PROG_LB.f_$lb -side left -fill both -expand 1
		pack $PROG_LB.l_$lb -side top -fill x -in $PROG_LB.f_$lb 
		pack $PROG_LB.$lb -side top -fill both \
			-expand true -in $PROG_LB.f_$lb
	    }
	    
	    set lb [lindex $prog_boxes 0]
	    set lb_cur_dtmf "$PROG_LB.$lb"
	    set lb [lindex $prog_boxes 1]
	    set lb_ref_dtmf "$PROG_LB.$lb"

	    for {set i 0} {$i < $num_items} {incr i} {
		
		$lb_cur_dtmf insert $i ""
		$lb_ref_dtmf insert $i ""
	    }

	}

	foreach box $prog_boxes {
	    
	    lappend LB_lboxes $PROG_LB.$box
	}
	update
	bind_listboxes

	if {[string match $prog_fp ""] == 0} {
	    catch {close $prog_fp}
	    set prog_fp ""
	}
	catch {set prog_fp [open $progress_file "r"]}
	if [string match $prog_fp ""]  {
	    catch {
		set prog_fp [open $progress_file "w"]
		close $prog_fp
		set prog_fp [open $progress_file "r"]
	    }
	}
	if {[string match $prog_fp ""] == 0} {
	    fconfigure $prog_fp -blocking 0 -buffering line

	    fileevent $prog_fp readable {
		
		set str [gets $prog_fp]
		
		if {[string match $str ""] == 0} {
		    $prog_w.t.out insert 1.0 "$str\n"
		    prog_process $str
		} else {
		    update idletasks
		}
	    }
	}
	
    }
}


proc prog_process {str} {
    global num_items item_number 
    global prog_spknum prog_cur_dtmf prog_ref_dtmf 
    global lb_cur_dtmf lb_ref_dtmf prog_w

    if { [string match $str ""] == 0} {
	
	set item_num -1
	set prog_spknum ""
	set prog_cur_dtmf ""
	set prog_ref_dtmf ""
	set dtmfs ""
	if [scan $str "%d, %d, %\[^\n\]" prog_spknum item_num dtmfs] {
	    
	    set delim [string first "^" $dtmfs]
	    if { $delim == -1} {
		set prog_cur_dtmf $dtmfs
		set prog_ref_dtmf ""
		
	    } else {
		set prog_cur_dtmf [string trim [string trim \
			[string range $dtmfs 0 [expr $delim -1]]]]
		
		set prog_ref_dtmf [string trim [string trim \
			[string range $dtmfs [expr $delim+1] end ]]]
	    }
	    
#	    puts "$dtmfs ($delim) -> >$prog_cur_dtmf<, >$prog_ref_dtmf<\n"
	    incr item_num
	    #	    puts "spk = $prog_spknum, it = $item_num, dtmf = $prog_cur_dtmf, ref_dtmf = $prog_ref_dtmf"
	    if {($item_num > 0) && \
		    ($item_num <= $num_items)} {
		
		$lb_cur_dtmf delete [expr $item_num -1]
		$lb_cur_dtmf insert [expr $item_num -1] $prog_cur_dtmf
		$lb_ref_dtmf delete [expr $item_num -1]
		$lb_ref_dtmf insert [expr $item_num -1] $prog_ref_dtmf
		if {$item_num != $item_number} {
		    LBviewit $item_num
		}
	    }
	} 
    }
}
# end of file
#

